@@ -13,8 +13,6 @@ import gc
 from math import ceil
 
 from sklearn.exceptions import NotFittedError
-from sklearn.preprocessing import LabelEncoder
-from sklearn.neighbors import KNeighborsClassifier
 import pandas as pd
 import numpy as np
 import plotly.graph_objs as go
@@ -159,28 +157,6 @@ class MonetModel:
         return pc_scores
 
 
-    def transfer_labels(
-            self, ref_matrix: ExpMatrix, ref_cell_labels: pd.Series,
-            target_matrix: ExpMatrix,
-            num_neighbors: int = 20, **kwargs) -> pd.Series:
-        
-        le = LabelEncoder()
-        
-        ref_pc_scores = self.transform(ref_matrix)
-        y_ref = le.fit_transform(ref_cell_labels.values)
-
-        clf = KNeighborsClassifier(n_neighbors=num_neighbors, **kwargs)
-        clf.fit(ref_pc_scores.values, y_ref)
-        
-        target_pc_scores = self.transform(target_matrix)
-        y_pred = clf.predict(target_pc_scores.values)    
-        y_pred = le.inverse_transform(y_pred)
-
-        target_cell_labels = pd.Series(index=target_matrix.cells, data=y_pred)
-        
-        return target_cell_labels
-
-
     def _determine_num_components(self, matrix: ExpMatrix) -> None:
         """Use MCV to determine the optimum number of PCs.
         
@@ -415,7 +391,7 @@ class MonetModel:
             for agg_step in range(self.num_aggregation_steps):
 
                 _LOGGER.info('Now performing aggregation step %d/%d...',
-                            agg_step, self.num_aggregation_steps)
+                            agg_step+1, self.num_aggregation_steps)
 
                 # kNN aggregation
                 agg_matrix = aggregate_neighbors(
